#!/bin/sh
SDK=/Developer/SDKs/MacOSX10.5.sdk
if [ $# -eq 1 ]
then
SDK=$1
fi
CFLAGS="-m32 -fobjc-abi-version=1 -Wno-endif-labels -isysroot ${SDK} -mmacosx-version-min=10.5";export CFLAGS
rm -rf usr Developer System
h-to-ffi.sh ${SDK}/System/Library/Frameworks/Quartz.framework/Headers/Quartz.h


